import { ɵɵdefineInjectable, Injectable, Component, Input, NgModule } from '@angular/core';
import { Subject } from 'rxjs';
import { finalize } from 'rxjs/operators';

class NgLoadingSpinnerService {
    constructor() {
        /** Progress state */
        this.state = new Subject();
        this.isSpinning1 = false;
    }
    /** Start spinning */
    start() {
        if (this.isSpinning()) {
            return;
        }
        this.isSpinning1 = true;
        this.state.next(true);
    }
    /** Stop spinning */
    stop() {
        if (!this.isSpinning()) {
            return;
        }
        this.isSpinning1 = false;
        /** if spinning stop it */
        this.state.next(false);
    }
    isSpinning() {
        return this.isSpinning1;
    }
}
NgLoadingSpinnerService.ɵprov = ɵɵdefineInjectable({ factory: function NgLoadingSpinnerService_Factory() { return new NgLoadingSpinnerService(); }, token: NgLoadingSpinnerService, providedIn: "root" });
NgLoadingSpinnerService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
NgLoadingSpinnerService.ctorParameters = () => [];

class NgLoadingSpinnerInterceptor {
    constructor(spinnerService) {
        this.spinnerService = spinnerService;
        this.requestCounter = 0;
    }
    intercept(req, next) {
        this.spinnerService.start();
        this.requestCounter++;
        return next.handle(req)
            .pipe(finalize(() => {
            this.requestCounter--;
            if (this.requestCounter === 0) {
                this.spinnerService.stop();
            }
        }));
    }
}
NgLoadingSpinnerInterceptor.decorators = [
    { type: Injectable }
];
NgLoadingSpinnerInterceptor.ctorParameters = () => [
    { type: NgLoadingSpinnerService }
];

class NgLoadingSpinnerComponent {
    constructor(ngLoadingSpinnerService) {
        this.ngLoadingSpinnerService = ngLoadingSpinnerService;
        this.color = '#000000';
        this.top = 105;
        this.ngLoadingSpinnerService.state.subscribe((r) => {
            this.show = r;
        });
    }
    ngOnInit() {
    }
    ngOnDrestroy() {
        this.ngLoadingSpinnerService.state.unsubscribe();
    }
}
NgLoadingSpinnerComponent.decorators = [
    { type: Component, args: [{
                // tslint:disable-next-line:component-selector
                selector: 'ng-loading-spinner',
                template: `
    <div [hidden]="!show" id="loading-bar-spinner" [style.top]="top + 'px'">
      <div [style.borderColor]="color" class="spinner-icon"></div>
    </div>
  `,
                styles: ["@-webkit-keyframes ball-clip-rotate{0%{transform:rotate(0deg)}50%{transform:rotate(180deg)}to{transform:rotate(1turn)}}@keyframes ball-clip-rotate{0%{transform:rotate(0deg)}50%{transform:rotate(180deg)}to{transform:rotate(1turn)}}#loading-bar,#loading-bar-spinner{-webkit-pointer-events:none;pointer-events:none;transition:all linear;transition-duration:.35s}#loading-bar-spinner.ng-enter,#loading-bar-spinner.ng-leave.ng-leave-active,#loading-bar.ng-enter,#loading-bar.ng-leave.ng-leave-active{filter:alpha(opacity=0);opacity:0}#loading-bar-spinner.ng-enter.ng-enter-active,#loading-bar-spinner.ng-leave,#loading-bar.ng-enter.ng-enter-active,#loading-bar.ng-leave{filter:alpha(opacity=100);opacity:1}#loading-bar .bar{background:rgba(0,0,0,.15);border-bottom-right-radius:1px;border-top-right-radius:1px;height:70px;left:0;position:fixed;top:0;transition:width;transition-duration:.35s;width:100%;z-index:10002}#loading-bar .peg{border-radius:100%;box-shadow:1px 0 6px 1px #fff;filter:alpha(opacity=45);height:2px;opacity:.45;position:absolute;right:0;top:0;width:70px;z-index:99999}#loading-bar-spinner{background:#fff;border-radius:50%;box-shadow:0 2px 5px rgba(0,0,0,.16),0 2px 10px rgba(0,0,0,.12);left:50%;margin-left:-28px;padding:14px;position:fixed;text-align:center;top:105px;z-index:999999}#loading-bar-spinner .spinner-icon{-webkit-animation:ball-clip-rotate .75s linear infinite;animation:ball-clip-rotate .75s linear infinite;background:transparent!important;border:2px solid red;border-bottom-color:transparent!important;border-radius:100%;display:inline-block;float:left;height:28px;margin:0;width:28px}#loading-bar-spinner:after,#loading-bar-spinner:before{content:\" \";display:table}#loading-bar-spinner:after{clear:both}"]
            },] }
];
NgLoadingSpinnerComponent.ctorParameters = () => [
    { type: NgLoadingSpinnerService }
];
NgLoadingSpinnerComponent.propDecorators = {
    color: [{ type: Input }],
    top: [{ type: Input }]
};

class NgLoadingSpinnerModule {
}
NgLoadingSpinnerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgLoadingSpinnerComponent],
                imports: [],
                exports: [NgLoadingSpinnerComponent],
                providers: [NgLoadingSpinnerService]
            },] }
];

/*
 * Public API Surface of ng-loading-spinner
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgLoadingSpinnerComponent, NgLoadingSpinnerInterceptor, NgLoadingSpinnerModule, NgLoadingSpinnerService };
//# sourceMappingURL=ng-loading-spinner.js.map
